package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"applet/app/utils"
	"code.fnuoos.com/zhimeng/model.git/src/implement"
	"github.com/gin-gonic/gin"
)

// Base
// @Summary    	 右上角基本数据
// @Tags         首页------嘉俊
// @Description  首页-右上角基本数据
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/index/base [GET]
func Base(c *gin.Context) {
	user := svc.GetUser(c)
	name := user.Username
	res := map[string]string{
		"account_id": utils.IntToStr(user.AdmId),
		"name":       name,
		"is_super":   "0",
		"account":    user.Username,
		"logo":       "",
		"memo":       user.Memo,
		"label":      "",
		"seo_logo":   "",
		"seo_title":  "",
	}
	if user.IsSuperAdministrator == 1 {
		res["is_super"] = "1"
	}
	NewAdminRoleDb := implement.NewAdminRoleDb(svc.MasterDb(c))
	role, _ := NewAdminRoleDb.GetAdminRoleByAdminId(user.AdmId)
	if role != nil {
		NewRoleDb := implement.NewRoleDb(svc.MasterDb(c), role.RoleId)
		getRole, _ := NewRoleDb.GetRole()
		if getRole != nil {
			res["logo"] = getRole.Logo
			res["label"] = getRole.Label
			res["seo_logo"] = getRole.SeoLogo
			res["seo_title"] = getRole.SeoTitle
		}
	}
	e.OutSuc(c, res, nil)
	return
}

// IndexTotal
// @Summary    	 统计数据
// @Tags         首页------嘉俊
// @Description  首页-统计数据
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/index/total [GET]
func IndexTotal(c *gin.Context) {
	svc.IndexTotal(c)
}

// IndexAppList
// @Summary    	 应用数据
// @Tags         首页------嘉俊
// @Description  首页-应用数据
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.IndexAppListReq   true   "请求参数"
// @Success      200   {object}	  md.IndexAppListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/index/app/list [POST]
func IndexAppList(c *gin.Context) {
	var req md.IndexAppListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.IndexAppList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// IndexAppListTable
// @Summary    	 应用数据-每个应用的折线图
// @Tags         首页------嘉俊
// @Description  首页-应用数据-每个应用的折线图
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.IndexAppListTableReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/index/app/list/table [POST]
func IndexAppListTable(c *gin.Context) {
	var req md.IndexAppListTableReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.BeforeSevenPoint(c, req)
	e.OutSuc(c, res, nil)
	return
}
